@@ -7,7 +7,8 @@ def server():
 
 
 @server.command()
-def run():
+@click.pass_context
+def run(ctx):
     from fpx.app import run_app
 
-    run_app()
+    run_app(ctx.obj)
