@@ -14,7 +14,7 @@ def ticket():
 @ticket.command()
 @click.pass_obj
 def list(app: Sanic):
-    for ticket in app.DbSession().query(Ticket):
+    for ticket in app.ctx.db_session().query(Ticket):
         click.echo(f"{ticket.id}({ticket.created_at}):")
         for item in ticket.items:
             click.echo(f"\t{item}")
@@ -26,7 +26,7 @@ def list(app: Sanic):
 @click.option("--all", is_flag=True)
 @click.argument("id", required=False)
 def drop(app: Sanic, all: bool, id: Optional[str] = None):
-    sess = app.DbSession()
+    sess = app.ctx.db_session()
     q = sess.query(Ticket)
     if id:
         q.filter_by(id=id).delete()
